@@ -403,8 +403,7 @@ class ServiceIndicator(Gio.Application):
         self.autostart = configuration.get('autostart')
         self.version = configuration.get('version')
         self.theme = configuration.get('theme')
-        self.active_icon = os.path.abspath(
-            common.STATUS_ICON[configuration.get('theme')])
+        self.active_icon = common.STATUS_ICON[configuration.get('theme')]
         self.attention_icon = common.STATUS_ICON[self.theme+"-attention"]
         self.show = configuration.get('show')
         self.notifications_enabled = configuration.get('notifications')
@@ -502,11 +501,11 @@ this program. If not, see <http://www.gnu.org/licenses/>.
         about_dialog.set_documenters([
             'Slimbook <dev@slimbook.es>'])
         about_dialog.set_translator_credits(_('translator-credits'))
-        size = 125
-        about_dialog.set_icon(GdkPixbuf.Pixbuf.new_from_file_at_scale(
-            common.ICON, size, size, True))
-        about_dialog.set_logo(GdkPixbuf.Pixbuf.new_from_file_at_scale(
-            common.ICON, size, size, True))
+
+        theme = Gtk.IconTheme()
+        pix = theme.load_icon(icon_name = common.ICON, size = 125, flags = Gtk.IconLookupFlags.FORCE_SYMBOLIC)
+        about_dialog.set_icon(pix)
+        about_dialog.set_logo(pix)
         about_dialog.set_program_name(common.APPNAME)
         return about_dialog
 
@@ -582,8 +581,9 @@ class ReportDialog(Gtk.Window):
         self.connect('delete-event',self.on_report_delete_event)
                 
         self.set_position(Gtk.WindowPosition.CENTER_ALWAYS)
-        self.set_icon(GdkPixbuf.Pixbuf.new_from_file_at_scale(
-            common.ICON, 64, 64, True))
+        theme = Gtk.IconTheme()
+        pix = theme.load_icon(icon_name = common.ICON, size = 64, flags = Gtk.IconLookupFlags.FORCE_SYMBOLIC)
+        self.set_icon(pix)
 
         header = Gtk.HeaderBar()
         header.set_title(_('Generate report'))
@@ -754,8 +754,9 @@ class PreferencesDialog(Gtk.Window):
         self.connect('delete-event',self.on_delete_event)
         
         self.set_position(Gtk.WindowPosition.CENTER_ALWAYS)
-        self.set_icon(GdkPixbuf.Pixbuf.new_from_file_at_scale(
-            common.ICON, 64, 64, True))
+        theme = Gtk.IconTheme()
+        pix = theme.load_icon(icon_name = common.ICON, size = 64, flags = Gtk.IconLookupFlags.FORCE_SYMBOLIC)
+        self.set_icon(pix)
 
         header = Gtk.HeaderBar()
         header.set_title(_('Slimbook Preferences'))
@@ -815,6 +816,13 @@ class PreferencesDialog(Gtk.Window):
         table1.attach(self.switch5, 1, 2, 11, 12, xpadding=15, ypadding=15,
                       xoptions=Gtk.AttachOptions.SHRINK)
         
+        label6 = Gtk.Label(label=_('AC Notifications') + ':')
+        label6.set_halign(Gtk.Align.CENTER)
+        table1.attach(label6, 0, 1, 12, 13, xpadding=15, ypadding=15)
+        self.switch6 = Gtk.Switch()
+        table1.attach(self.switch6, 1, 2, 12, 13, xpadding=15, ypadding=15,
+                      xoptions=Gtk.AttachOptions.SHRINK)
+
         self.load_preferences()
         
         self.changes = False
@@ -824,6 +832,7 @@ class PreferencesDialog(Gtk.Window):
         self.switch3.connect('state-set',self.on_switch_state_set)
         self.switch4.connect('state-set',self.on_switch_state_set)
         self.switch5.connect('state-set',self.on_switch_state_set)
+        self.switch6.connect('state-set',self.on_switch_state_set)
         
         self.show_all()
 
@@ -856,6 +865,7 @@ class PreferencesDialog(Gtk.Window):
         self.switch3.set_active(configuration.get('notifications') == True)
         self.switch4.set_active(configuration.get('trackpad-lock') == True)
         self.switch5.set_active(configuration.get('power-profile') == True)
+        self.switch6.set_active(configuration.get('ac-notifications') == True)
     
     def save_preferences(self):
 
@@ -873,11 +883,13 @@ class PreferencesDialog(Gtk.Window):
         configuration.set('notifications', self.switch3.get_active())
         configuration.set('trackpad-lock', self.switch4.get_active())
         configuration.set('power-profile', self.switch5.get_active())
+        configuration.set('ac-notifications', self.switch6.get_active())
         configuration.save()
         
         settings = {}
         settings[common.OPT_TRACKPAD_LOCK] = self.switch4.get_active()
         settings[common.OPT_POWER_PROFILE] = self.switch5.get_active()
+        settings[common.OPT_AC_NOTIFICATIONS] = self.switch6.get_active()
         update_server_settings(settings)
         
 class SystemInfoDialog(Gtk.Dialog):
